@@ -53,3 +53,36 @@ sub Upload {
 1;
 
 __END__
+
+=head1 DESCRIPTION
+
+Program for unit tests
+
+=head1 PUBLIC METHODS
+
+=over 4
+
+=item apply_zap 
+
+=item reset
+
+=item scalar
+
+=item UpOne
+
+=item Upload
+
+=back
+
+=head1 AUTHOR
+
+Eric Wolf
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (C) 2011 Eric Wolf
+
+This module is free software; it can be used under the same terms as perl
+itself.
+
+=cut
